#line 2 "gen/gen_lexer.inc"

#line 4 "gen/gen_lexer.inc"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 145
#define YY_END_OF_BUFFER 146
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[234] =
    {   0,
        0,    0,    0,    0,  146,  144,  143,  143,  144,  140,
      141,  142,  144,  144,  144,    2,    2,  139,  139,  139,
      139,  139,  139,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  136,  138,  135,  137,  143,    0,    3,
        0,    2,    0,    0,  132,  131,    0,    0,    0,  139,
        1,  139,  139,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  139,  120,  112,  119,  139,  139,
      139,  139,  139,  139,  139,  139,  139,  139,  113,  139,
      139,    6,    7,    8,    9,   10,   11,   12,   13,   14,
       15,  136,  135,  134,  133,    0,    0,  131,    2,    2,

       98,  139,  108,  111,  110,  109,  127,  139,  125,  139,
      122,  139,  139,  126,  139,  106,  104,  121,  118,  139,
      123,  102,  101,   96,  100,  103,   97,  124,   99,  139,
       16,   17,   18,   19,   20,   21,   22,   23,   24,   25,
       26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
       36,   37,   38,   39,   40,   41,   42,   43,   44,   45,
       46,   47,   48,   49,   50,   51,   52,   53,   54,   55,
       56,   57,   58,   59,   60,   61,   62,   63,   64,   65,
       66,   67,   68,   69,   70,   71,   72,   73,   74,   75,
       76,   77,   78,   79,   80,   81,   82,   83,   84,   85,

       86,    0,    4,   87,  139,  139,   93,  139,  139,  139,
      107,  139,   90,   89,   94,   88,   91,   95,   92,    0,
      105,  130,  129,  128,  139,  114,  117,  116,    0,  115,
        0,    5,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    1,    1,    1,    1,    1,    5,
        6,    7,    1,    8,    9,   10,   11,   12,   13,   14,
       15,   16,   17,   18,   19,   20,   21,   22,    1,    1,
        1,    1,    1,    1,   23,   23,   23,   23,   23,   23,
       23,   23,   24,   24,   23,   24,   23,   23,   24,   23,
       24,   23,   24,   23,   24,   23,   24,   23,   24,   23,
        1,   25,    1,    1,   24,    1,   26,   27,   28,   29,

       30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
       40,   41,   42,   43,   44,   45,   46,   47,   48,   49,
       24,   23,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[50] =
    {   0,
        1,    2,    3,    1,    1,    1,    4,    1,    1,    1,
        4,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    2,    6,    2,    1,    6,    6,    6,    6,    6,
        6,    6,    6,    2,    2,    6,    2,    6,    6,    2,
        6,    2,    6,    2,    6,    2,    6,    2,    6
    } ;

static const flex_int16_t yy_base[241] =
    {   0,
        0,    0,   47,   48,  144,  991,   50,   54,   56,  991,
      991,  991,    0,   27,   55,   30,    0,   62,   65,   67,
       70,   76,   80,   83,   98,  113,  115,  123,  126,  119,
      162,  128,  207,    0,  991,   69,  136,   88,   70,  991,
      137,    0,   99,  106,  991,    0,    0,  121,  149,  154,
      991,  166,  178,  171,  176,  194,  212,  215,  228,  230,
      233,  241,  243,  246,  256,  180,  259,  272,  277,  280,
      284,  287,  293,  298,  302,  305,  316,  319,  326,  331,
      333,  341,  362,  372,  382,  392,  402,  412,  422,  442,
      444,    0,  116,  991,  991,  104,   67,    0,    0,  177,

      446,  448,  450,  453,  455,  457,  459,  471,  480,  482,
      484,  488,  493,  495,  497,  505,  509,  518,  530,  532,
      534,  536,  539,  541,  543,  557,  564,  578,  580,  582,
      585,  587,  590,  592,  594,  603,  608,  615,  617,  619,
      624,  626,  629,  631,  633,  640,  642,  647,  654,  656,
      658,  663,  665,  668,  670,  672,  679,  681,  686,  693,
      695,  697,  702,  704,  707,  709,  711,  718,  720,  725,
      732,  734,  736,  741,  743,  746,  748,  750,  757,  759,
      764,  771,  773,  775,  780,  782,  785,  787,  789,  796,
      798,  803,  810,  812,  814,  819,  821,  824,  826,  828,

      835,   72,  991,  837,  842,  849,  851,  853,  858,  860,
      863,  865,  881,  886,  889,  896,  898,  902,  904,   57,
      907,  910,  912,  914,  919,  925,  928,  935,   64,  937,
       58,  991,  991,  959,  965,   72,  970,  976,  982,  984
    } ;

static const flex_int16_t yy_def[241] =
    {   0,
      233,    1,  234,  234,  233,  233,  233,  233,  235,  233,
      233,  233,  236,  233,  233,  236,  236,  237,  237,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
      237,  237,  237,  238,  233,  233,  233,  233,  235,  233,
      235,  236,  233,  233,  233,  239,  240,  233,  233,  237,
      233,  237,  237,  237,  237,  237,  237,  237,  237,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
      237,  237,   33,   33,   33,   33,   33,   33,   33,  237,
      237,  238,  233,  233,  233,  233,  233,  239,  240,  233,

      237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  237,

      237,  233,  233,  237,  237,  237,  237,  237,  237,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  233,
      237,  237,  237,  237,  237,  237,  237,  237,  233,  237,
      233,  233,    0,  233,  233,  233,  233,  233,  233,  233
    } ;

static const flex_int16_t yy_nxt[1041] =
    {   0,
        6,    7,    8,    9,   10,   11,    6,   12,   13,   14,
       15,   16,   17,   17,   17,   17,   17,   17,   17,   17,
       17,    6,   18,   18,    6,   19,   20,   21,   22,   23,
       24,   18,   18,   18,   25,   18,   26,   27,   28,   18,
       29,   18,   30,   31,   18,   32,   18,   18,   33,   35,
       35,   38,   38,   36,   36,   38,   38,   37,   37,   40,
       43,   45,   47,   49,   49,   46,   49,   49,   49,   49,
       44,   49,   49,   40,   48,   93,   42,   49,   49,   94,
       41,   49,   49,   51,   49,   49,   51,  232,   51,   38,
       38,   51,  231,   52,   41,   58,   54,   51,   55,   49,

       49,   51,  229,   56,   51,   57,   61,   62,  220,   60,
       53,  203,   64,   59,   49,   49,   49,   49,   63,   51,
       49,   49,   93,   65,   49,   49,   94,   49,   49,   49,
       49,  202,  100,  100,   51,   97,   51,   96,   66,  233,
       51,   67,   95,  233,   51,  233,   68,   51,   73,   51,
       49,   49,  233,   72,  100,   49,   49,  233,   69,  233,
       70,  233,   71,   49,   49,  233,   81,   49,   49,  233,
       51,  233,   49,   49,  233,   51,  233,   49,   49,   49,
       49,   49,   49,   51,  233,  233,  233,   51,  100,  100,
      233,   74,   51,   75,  101,   49,   49,   51,   76,   51,

       77,   51,  233,  233,   78,  104,   79,   80,   49,   49,
      100,  102,  103,   49,   49,   51,   49,   49,   82,   83,
       84,   85,   86,   87,   88,   89,   90,   91,   51,   49,
       49,   49,   49,   51,   49,   49,   51,  233,  105,  233,
      233,  106,   49,   49,   49,   49,  233,   49,   49,   51,
      233,   51,  233,  233,   51,  233,  233,   49,   49,  107,
       49,   49,   51,  233,   51,  233,  113,   51,  233,  110,
      108,  233,  109,   49,   49,  112,  111,   51,   49,   49,
       51,   49,   49,  233,  115,   49,   49,  114,   49,   49,
      233,  233,  116,   51,   49,   49,  233,  233,   51,   49,

       49,   51,  233,   49,   49,   51,   49,   49,   51,  233,
      117,  233,  120,  233,   51,  233,  118,   49,   49,   51,
       49,   49,  233,   51,  119,  233,   51,   49,   49,  233,
      121,  123,   49,   49,   49,   49,  233,   51,  233,  122,
       51,  124,   49,   49,  233,  126,  233,   51,  233,  125,
      233,  233,   51,  233,   51,  127,  233,  129,  233,  233,
      233,  233,   51,  233,  233,  233,  233,  233,  233,  233,
      128,  233,  130,  131,  132,  133,  134,  135,  136,  137,
      138,  139,  140,  141,  142,  143,  144,  145,  146,  147,
      148,  149,  150,  151,  152,  153,  154,  155,  156,  157,

      158,  159,  160,  161,  162,  163,  164,  165,  166,  167,
      168,  169,  170,  171,  172,  173,  174,  175,  176,  177,
      178,  179,  180,  181,  182,  183,  184,  185,  186,  187,
      188,  189,  190,  191,  192,  193,  194,  195,  196,  197,
      198,  199,  200,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,  201,   49,   49,   49,   49,   49,   49,
       49,   49,  233,   51,  233,   51,  233,   51,  233,   51,
      233,   51,   49,   49,   51,  233,   51,  233,   51,  204,
       51,   49,   49,   49,   49,   49,   49,  233,  205,   49,
       49,  233,   51,  233,   49,   49,   49,   49,   49,   49,

      233,   51,  233,   51,  233,   51,   49,   49,  233,   51,
       49,   49,  233,  206,   51,  233,   51,  208,   51,   49,
       49,  233,  207,  233,  210,  233,   51,  233,  233,  209,
       51,   49,   49,   49,   49,   49,   49,   49,   49,   51,
       49,   49,   49,   49,   49,   49,  233,  211,  233,  233,
      233,   51,  233,   51,  233,   51,  233,   51,   49,   49,
       51,  233,   51,  233,   51,   49,   49,  233,  212,  213,
      233,  233,  214,  233,  215,  233,  216,  233,   51,   49,
       49,   49,   49,   49,   49,   51,   49,   49,   49,   49,
      217,   49,   49,   49,   49,   49,   49,  218,  233,   51,

      233,   51,  233,   51,   49,   49,   51,  233,   51,   49,
       49,   51,  233,   51,  233,   51,   49,   49,   49,   49,
       49,   49,  219,  233,   51,   49,   49,   49,   49,   51,
       49,   49,   49,   49,   49,   49,   51,  233,   51,  233,
       51,   49,   49,   49,   49,   51,  233,   51,   49,   49,
       51,  233,   51,  233,   51,   49,   49,   49,   49,   49,
       49,   51,  233,   51,   49,   49,   49,   49,   51,   49,
       49,   49,   49,   49,   49,   51,  233,   51,  233,   51,
       49,   49,   49,   49,   51,  233,   51,   49,   49,   51,
      233,   51,  233,   51,   49,   49,   49,   49,   49,   49,

       51,  233,   51,   49,   49,   49,   49,   51,   49,   49,
       49,   49,   49,   49,   51,  233,   51,  233,   51,   49,
       49,   49,   49,   51,  233,   51,   49,   49,   51,  233,
       51,  233,   51,   49,   49,   49,   49,   49,   49,   51,
      233,   51,   49,   49,   49,   49,   51,   49,   49,   49,
       49,   49,   49,   51,  233,   51,  233,   51,   49,   49,
       49,   49,   51,  233,   51,   49,   49,   51,  233,   51,
      233,   51,   49,   49,   49,   49,   49,   49,   51,  233,
       51,   49,   49,   49,   49,   51,   49,   49,   49,   49,
       49,   49,   51,  233,   51,  233,   51,   49,   49,   49,

       49,   51,  233,   51,   49,   49,   51,  233,   51,  233,
       51,   49,   49,   49,   49,   49,   49,   51,  233,   51,
       49,   49,   49,   49,   51,   49,   49,   49,   49,   49,
       49,   51,  233,   51,  233,   51,   49,   49,   49,   49,
       51,  233,   51,   49,   49,   51,  233,   51,  233,   51,
       49,   49,   49,   49,   49,   49,   51,  233,   51,   49,
       49,   49,   49,   51,   49,   49,   49,   49,  233,  221,
       51,  233,   51,  233,   51,  233,  222,  233,  225,   51,
      233,   51,   49,   49,   51,  233,   51,   49,   49,  227,
       49,   49,  223,  233,  226,  233,  224,   49,   49,   49,

       49,  228,   51,   49,   49,   49,   49,   51,   49,   49,
       51,   49,   49,   49,   49,   49,   49,   51,  233,   51,
       49,   49,  233,   51,  233,   51,   49,   49,   51,   49,
       49,   51,  233,   51,  233,   51,   49,   49,   49,   49,
       51,  233,  233,  233,  233,  233,   51,  233,  233,   51,
      233,  233,  233,  233,  230,  233,   51,  233,   51,   34,
       34,   34,   34,   34,   34,   39,   39,   39,   39,   39,
       39,   50,   50,  233,   50,   50,   92,   92,  233,  233,
       92,   92,   98,   98,  233,   98,   98,   98,   99,   99,
        5,  233,  233,  233,  233,  233,  233,  233,  233,  233,

      233,  233,  233,  233,  233,  233,  233,  233,  233,  233,
      233,  233,  233,  233,  233,  233,  233,  233,  233,  233,
      233,  233,  233,  233,  233,  233,  233,  233,  233,  233,
      233,  233,  233,  233,  233,  233,  233,  233,  233,  233
    } ;

static const flex_int16_t yy_chk[1041] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    3,
        4,    7,    7,    3,    4,    8,    8,    3,    4,    9,
       14,   15,   16,   18,   18,   15,   19,   19,   20,   20,
       14,   21,   21,   39,   16,   36,  236,   22,   22,   36,
        9,   23,   23,   18,   24,   24,   19,  231,   20,   38,
       38,   21,  229,   19,   39,   21,   20,   22,   20,   25,

       25,   23,  220,   20,   24,   20,   23,   23,  202,   22,
       19,   97,   24,   21,   26,   26,   27,   27,   23,   25,
       30,   30,   93,   25,   28,   28,   93,   29,   29,   32,
       32,   96,   48,   48,   26,   44,   27,   43,   26,   41,
       30,   26,   37,    5,   28,    0,   26,   29,   30,   32,
       49,   49,    0,   29,   48,   50,   50,    0,   26,    0,
       27,    0,   28,   31,   31,    0,   32,   52,   52,    0,
       49,    0,   54,   54,    0,   50,    0,   55,   55,   53,
       53,   66,   66,   31,    0,    0,    0,   52,  100,  100,
        0,   31,   54,   31,   52,   56,   56,   55,   31,   53,

       31,   66,    0,    0,   31,   55,   31,   31,   33,   33,
      100,   53,   54,   57,   57,   56,   58,   58,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   59,
       59,   60,   60,   57,   61,   61,   58,    0,   56,    0,
        0,   57,   62,   62,   63,   63,    0,   64,   64,   59,
        0,   60,    0,    0,   61,    0,    0,   65,   65,   58,
       67,   67,   62,    0,   63,    0,   62,   64,    0,   60,
       59,    0,   59,   68,   68,   61,   60,   65,   69,   69,
       67,   70,   70,    0,   64,   71,   71,   63,   72,   72,
        0,    0,   65,   68,   73,   73,    0,    0,   69,   74,

       74,   70,    0,   75,   75,   71,   76,   76,   72,    0,
       69,    0,   72,    0,   73,    0,   70,   77,   77,   74,
       78,   78,    0,   75,   71,    0,   76,   79,   79,    0,
       73,   75,   80,   80,   81,   81,    0,   77,    0,   74,
       78,   76,   82,   82,    0,   77,    0,   79,    0,   76,
        0,    0,   80,    0,   81,   78,    0,   80,    0,    0,
        0,    0,   82,    0,    0,    0,    0,    0,    0,    0,
       79,    0,   81,   83,   83,   83,   83,   83,   83,   83,
       83,   83,   83,   84,   84,   84,   84,   84,   84,   84,
       84,   84,   84,   85,   85,   85,   85,   85,   85,   85,

       85,   85,   85,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   88,   88,   88,   88,   88,   88,   88,
       88,   88,   88,   89,   89,   89,   89,   89,   89,   89,
       89,   89,   89,   90,   90,   91,   91,  101,  101,  102,
      102,  103,  103,   90,  104,  104,  105,  105,  106,  106,
      107,  107,    0,   90,    0,   91,    0,  101,    0,  102,
        0,  103,  108,  108,  104,    0,  105,    0,  106,  101,
      107,  109,  109,  110,  110,  111,  111,    0,  102,  112,
      112,    0,  108,    0,  113,  113,  114,  114,  115,  115,

        0,  109,    0,  110,    0,  111,  116,  116,    0,  112,
      117,  117,    0,  108,  113,    0,  114,  112,  115,  118,
      118,    0,  110,    0,  115,    0,  116,    0,    0,  113,
      117,  119,  119,  120,  120,  121,  121,  122,  122,  118,
      123,  123,  124,  124,  125,  125,    0,  116,    0,    0,
        0,  119,    0,  120,    0,  121,    0,  122,  126,  126,
      123,    0,  124,    0,  125,  127,  127,    0,  120,  122,
        0,    0,  123,    0,  124,    0,  125,    0,  126,  128,
      128,  129,  129,  130,  130,  127,  131,  131,  132,  132,
      126,  133,  133,  134,  134,  135,  135,  127,    0,  128,

        0,  129,    0,  130,  136,  136,  131,    0,  132,  137,
      137,  133,    0,  134,    0,  135,  138,  138,  139,  139,
      140,  140,  130,    0,  136,  141,  141,  142,  142,  137,
      143,  143,  144,  144,  145,  145,  138,    0,  139,    0,
      140,  146,  146,  147,  147,  141,    0,  142,  148,  148,
      143,    0,  144,    0,  145,  149,  149,  150,  150,  151,
      151,  146,    0,  147,  152,  152,  153,  153,  148,  154,
      154,  155,  155,  156,  156,  149,    0,  150,    0,  151,
      157,  157,  158,  158,  152,    0,  153,  159,  159,  154,
        0,  155,    0,  156,  160,  160,  161,  161,  162,  162,

      157,    0,  158,  163,  163,  164,  164,  159,  165,  165,
      166,  166,  167,  167,  160,    0,  161,    0,  162,  168,
      168,  169,  169,  163,    0,  164,  170,  170,  165,    0,
      166,    0,  167,  171,  171,  172,  172,  173,  173,  168,
        0,  169,  174,  174,  175,  175,  170,  176,  176,  177,
      177,  178,  178,  171,    0,  172,    0,  173,  179,  179,
      180,  180,  174,    0,  175,  181,  181,  176,    0,  177,
        0,  178,  182,  182,  183,  183,  184,  184,  179,    0,
      180,  185,  185,  186,  186,  181,  187,  187,  188,  188,
      189,  189,  182,    0,  183,    0,  184,  190,  190,  191,

      191,  185,    0,  186,  192,  192,  187,    0,  188,    0,
      189,  193,  193,  194,  194,  195,  195,  190,    0,  191,
      196,  196,  197,  197,  192,  198,  198,  199,  199,  200,
      200,  193,    0,  194,    0,  195,  201,  201,  204,  204,
      196,    0,  197,  205,  205,  198,    0,  199,    0,  200,
      206,  206,  207,  207,  208,  208,  201,    0,  204,  209,
      209,  210,  210,  205,  211,  211,  212,  212,    0,  205,
      206,    0,  207,    0,  208,    0,  206,    0,  208,  209,
        0,  210,  213,  213,  211,    0,  212,  214,  214,  210,
      215,  215,  206,    0,  209,    0,  206,  216,  216,  217,

      217,  212,  213,  218,  218,  219,  219,  214,  221,  221,
      215,  222,  222,  223,  223,  224,  224,  216,    0,  217,
      225,  225,    0,  218,    0,  219,  226,  226,  221,  227,
      227,  222,    0,  223,    0,  224,  228,  228,  230,  230,
      225,    0,    0,    0,    0,    0,  226,    0,    0,  227,
        0,    0,    0,    0,  225,    0,  228,    0,  230,  234,
      234,  234,  234,  234,  234,  235,  235,  235,  235,  235,
      235,  237,  237,    0,  237,  237,  238,  238,    0,    0,
      238,  238,  239,  239,    0,  239,  239,  239,  240,  240,
      233,  233,  233,  233,  233,  233,  233,  233,  233,  233,

      233,  233,  233,  233,  233,  233,  233,  233,  233,  233,
      233,  233,  233,  233,  233,  233,  233,  233,  233,  233,
      233,  233,  233,  233,  233,  233,  233,  233,  233,  233,
      233,  233,  233,  233,  233,  233,  233,  233,  233,  233
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "src/lexer.l"
/* SPDX-License-Identifier: copyleft-next-0.3.1 */
/* Copyright 2023 Kim Kuparinen < kimi.h.kuparinen@gmail.com > */
#define YY_NO_INPUT 1
#line 6 "src/lexer.l"
#define FROM_LEXER
#include <tasm/parser.h>

static void update_yylloc(struct parser *parser, YYLTYPE *lloc, const char *text)
{
	(void)parser;

	lloc->first_line = lloc->last_line;
	lloc->first_column = lloc->last_column;

	for (size_t i = 0; text[i] != 0; ++i) {
		if (text[i] == '\n') {
			lloc->last_line++;
			/* flex uses 1 based indexing */
			lloc->last_column = 1;
		} else {
			lloc->last_column++;
		}
	}
}

#define YY_USER_ACTION update_yylloc(parser, yylloc, yytext);
#line 753 "gen/gen_lexer.inc"

#line 755 "gen/gen_lexer.inc"

#define INITIAL 0
#define SC_COMMENT 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 42 "src/lexer.l"


#line 1017 "gen/gen_lexer.inc"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 234 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 991 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 44 "src/lexer.l"
{
	/* strip trailing ':' */
	char *s = yytext + strlen(yytext);
	s[-1] = '\0';

	yylval->str = yytext;
	return label;
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 53 "src/lexer.l"
{
	yylval->tri = parse_imm(yytext);
	return imm;
}
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 58 "src/lexer.l"
{
	/* strip leading and trailing " */
	char *s = yytext + strlen(yytext);
	s[-1] = '\0';

	yylval->str = yytext + 1;
	return str;
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 67 "src/lexer.l"
{return set;}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 68 "src/lexer.l"
{return include;}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 70 "src/lexer.l"
{return x0;}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 71 "src/lexer.l"
{return x1;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 72 "src/lexer.l"
{return x2;}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 73 "src/lexer.l"
{return x3;}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 74 "src/lexer.l"
{return x4;}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 75 "src/lexer.l"
{return x5;}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 76 "src/lexer.l"
{return x6;}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 77 "src/lexer.l"
{return x7;}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 78 "src/lexer.l"
{return x8;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 79 "src/lexer.l"
{return x9;}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 80 "src/lexer.l"
{return x10;}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 81 "src/lexer.l"
{return x11;}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 82 "src/lexer.l"
{return x12;}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 83 "src/lexer.l"
{return x13;}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 84 "src/lexer.l"
{return x14;}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 85 "src/lexer.l"
{return x15;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 86 "src/lexer.l"
{return x16;}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 87 "src/lexer.l"
{return x17;}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 88 "src/lexer.l"
{return x18;}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 89 "src/lexer.l"
{return x19;}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 90 "src/lexer.l"
{return x20;}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 91 "src/lexer.l"
{return x21;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 92 "src/lexer.l"
{return x22;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 93 "src/lexer.l"
{return x23;}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 94 "src/lexer.l"
{return x24;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 95 "src/lexer.l"
{return x25;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 96 "src/lexer.l"
{return x26;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 97 "src/lexer.l"
{return x27;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 98 "src/lexer.l"
{return x28;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 99 "src/lexer.l"
{return x29;}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 100 "src/lexer.l"
{return x30;}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 101 "src/lexer.l"
{return x31;}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 102 "src/lexer.l"
{return x32;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 103 "src/lexer.l"
{return x33;}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 104 "src/lexer.l"
{return x34;}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 105 "src/lexer.l"
{return x35;}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 106 "src/lexer.l"
{return x36;}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 107 "src/lexer.l"
{return x37;}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 108 "src/lexer.l"
{return x38;}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 109 "src/lexer.l"
{return x39;}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 110 "src/lexer.l"
{return x40;}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 111 "src/lexer.l"
{return x41;}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 112 "src/lexer.l"
{return x42;}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 113 "src/lexer.l"
{return x43;}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 114 "src/lexer.l"
{return x44;}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 115 "src/lexer.l"
{return x45;}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 116 "src/lexer.l"
{return x46;}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 117 "src/lexer.l"
{return x47;}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 118 "src/lexer.l"
{return x48;}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 119 "src/lexer.l"
{return x49;}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 120 "src/lexer.l"
{return x50;}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 121 "src/lexer.l"
{return x51;}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 122 "src/lexer.l"
{return x52;}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 123 "src/lexer.l"
{return x53;}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 124 "src/lexer.l"
{return x54;}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 125 "src/lexer.l"
{return x55;}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 126 "src/lexer.l"
{return x56;}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 127 "src/lexer.l"
{return x57;}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 128 "src/lexer.l"
{return x58;}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 129 "src/lexer.l"
{return x59;}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 130 "src/lexer.l"
{return x60;}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 131 "src/lexer.l"
{return x61;}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 132 "src/lexer.l"
{return x62;}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 133 "src/lexer.l"
{return x63;}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 134 "src/lexer.l"
{return x64;}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 135 "src/lexer.l"
{return x65;}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 136 "src/lexer.l"
{return x66;}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 137 "src/lexer.l"
{return x67;}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 138 "src/lexer.l"
{return x68;}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 139 "src/lexer.l"
{return x69;}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 140 "src/lexer.l"
{return x70;}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 141 "src/lexer.l"
{return x71;}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 142 "src/lexer.l"
{return x72;}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 143 "src/lexer.l"
{return x73;}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 144 "src/lexer.l"
{return x74;}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 145 "src/lexer.l"
{return x75;}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 146 "src/lexer.l"
{return x76;}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 147 "src/lexer.l"
{return x77;}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 148 "src/lexer.l"
{return x78;}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 149 "src/lexer.l"
{return x79;}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 150 "src/lexer.l"
{return x80;}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 152 "src/lexer.l"
{return addi; /* i */}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 153 "src/lexer.l"
{return slti;}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 154 "src/lexer.l"
{return sgei;}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 155 "src/lexer.l"
{return seqi;}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 156 "src/lexer.l"
{return snei;}
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 157 "src/lexer.l"
{return unop;}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 158 "src/lexer.l"
{return diop;}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 159 "src/lexer.l"
{return slli;}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 160 "src/lexer.l"
{return srli;}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 161 "src/lexer.l"
{return sll;}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 162 "src/lexer.l"
{return srl;}
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 163 "src/lexer.l"
{return add;}
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 164 "src/lexer.l"
{return sub;}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 165 "src/lexer.l"
{return slt;}
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 166 "src/lexer.l"
{return sge;}
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 167 "src/lexer.l"
{return seq;}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 168 "src/lexer.l"
{return sne;}
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 169 "src/lexer.l"
{return lui;}
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 170 "src/lexer.l"
{return auipc;}
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 171 "src/lexer.l"
{return jal;}
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 172 "src/lexer.l"
{return jalr;}
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 173 "src/lexer.l"
{return beq;}
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 174 "src/lexer.l"
{return bne;}
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 175 "src/lexer.l"
{return blt;}
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 176 "src/lexer.l"
{return bge;}
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 177 "src/lexer.l"
{return ld;}
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 178 "src/lexer.l"
{return st;}
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 179 "src/lexer.l"
{return ecall;}
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 180 "src/lexer.l"
{return ebreak;}
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 181 "src/lexer.l"
{return pcall;}
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 182 "src/lexer.l"
{return fence;}
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 183 "src/lexer.l"
{return nop; /* meta */}
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 184 "src/lexer.l"
{return li;}
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 185 "src/lexer.l"
{return la;}
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 187 "src/lexer.l"
{return mul; /* m */}
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 188 "src/lexer.l"
{return diV;}
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 189 "src/lexer.l"
{return rem;}
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 191 "src/lexer.l"
{return stt; /* a */}
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 192 "src/lexer.l"
{return cst;}
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 193 "src/lexer.l"
{return ent;}
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 194 "src/lexer.l"
{return cat;}
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 196 "src/lexer.l"
{return csrrw; /* Zcsr */}
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 197 "src/lexer.l"
{return csrrs;}
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 198 "src/lexer.l"
{return csrrc;}
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 200 "src/lexer.l"
{/* skip line comments */}
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 202 "src/lexer.l"
{BEGIN(SC_COMMENT);}
	YY_BREAK

case 133:
YY_RULE_SETUP
#line 204 "src/lexer.l"
{++parser->comment_nesting;}
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 205 "src/lexer.l"
{
		if (parser->comment_nesting)
			--parser->comment_nesting;
		else
			BEGIN(INITIAL);
	}
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 212 "src/lexer.l"
{}
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 213 "src/lexer.l"
{}
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 214 "src/lexer.l"
{}
	YY_BREAK
case 138:
/* rule 138 can match eol */
YY_RULE_SETUP
#line 215 "src/lexer.l"
{}
	YY_BREAK

case 139:
YY_RULE_SETUP
#line 218 "src/lexer.l"
{
	yylval->str = yytext;
	return id;
}
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 223 "src/lexer.l"
{return LPAREN;}
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 224 "src/lexer.l"
{return RPAREN;}
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 225 "src/lexer.l"
{return COMMA;}
	YY_BREAK
case 143:
/* rule 143 can match eol */
YY_RULE_SETUP
#line 227 "src/lexer.l"
{/* skip whitespace */}
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 229 "src/lexer.l"
{
	struct src_issue issue;
	issue.loc = to_src_loc(yylloc);
	issue.fctx.fbuf = parser->buf;
	issue.fctx.fname = parser->fname;
	src_issue(issue, "unexpected token: %s", yytext);
	parser->failed = true;
}
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 237 "src/lexer.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1837 "gen/gen_lexer.inc"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(SC_COMMENT):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 234 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 234 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 233);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 237 "src/lexer.l"


